<?php
    /*
    Plugin Name: The Slide by SimpleReach
    Plugin URI: https://www.simplereach.com
    Description: After installation, you must click '<a href='options-general.php?page=SimpleReach-Slide'>Settings &rarr; SimpleReach Slide</a>' to turn on The Slide.
    Version: 0.5.3
    Author: SimpleReach
    Author URI: https://www.simplereach.com
    */

define('SRSLIDE_PLUGIN_VERSION', '0.5.3');
define('SRSLIDE_PLUGIN_URL', plugin_dir_url(__FILE__));
define('SRSLIDE_PLUGIN_SUPPORT_EMAIL', 'support@simplereach.com');
require_once('srslide_functions.php');
require_once('srslide_post.php');

/**
 * Insert The Slide by SimpleReach onto the post page
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param String $content the_content() output
 * @return String The content and The Slide code (if applicable)
 */
function srslide_insert_slide($content)
{
    global $post;
    $post_id = $post;
    if (is_object($post_id)) {
        $post_id = $post_id->ID;
    }

    // Return the content on anything other than post pages
    $recommend_pages = get_option('srslide_use_pages');
    if (!$recommend_pages == true) {
        $recommend_pages = false;
    }
    if (!is_single() && !is_page()) {
        return $content;
    }
    if (is_page() && $recommend_pages == false) {
        return $content;
    }

    // If the post isn't published yet, we don't need a slide
    if ($post->post_status != 'publish') {
        return $content;
    }

    $sr_pub_id = get_option('srslide_pid');

    // There is no point in continuing without a PID, so stop
    if (strlen($sr_pub_id) != 24) {
        return $content;
    }

    $title = get_sr_post_title($post);
    $tags = get_sr_post_tags($post);
    $disable_on_post = get_post_meta($post_id,'_srslide_disable_on_post',true);
    $published_date = $post->post_date_gmt;
    $canonical_url = urlencode(get_permalink($post->ID));
    $slide_logo = get_option('srslide_show_logo') ? 'true' : 'false';
    $header_text = get_option('srslide_header_text');

    // Ensure The Slide is enabled when it's supposed to be
    if (isset($disable_on_post) && $disable_on_post != true) {
        $disable_on_post = 'false';
    }

    $SRSLIDE_PLUGIN_VERSION = SRSLIDE_PLUGIN_VERSION;

// Get the JS ready to go
$rv = <<< SRSLIDE_SCRIPT_TAG
<!-- SimpleReach Slide Plugin Version: {$SRSLIDE_PLUGIN_VERSION} -->
<script type='text/javascript' id='simplereach-slide-tag'>
  __spr_config = {
    pid: '{$sr_pub_id}',
    title: '{$title}',
    ckw: '{$tags}',
    no_slide: {$disable_on_post},
    slide_logo: {$slide_logo},
    pub: '{$published_date}',
    url: '{$canonical_url}',
    header: '{$header_text}'
  };
  var content = document.getElementById('simplereach-slide-tag').parentNode, loc;
  if (content.className){ loc = '.' + content.className; }
  if (content.id){ loc = '#' + content.id; }
  __spr_config.loc = loc || content;
  (function(){
    var s = document.createElement('script');
    s.async = true;
    s.type = 'text/javascript';
    s.src = document.location.protocol + '//d8rk54i4mohrb.cloudfront.net/js/slide.js';
    __spr_config.css = document.location.protocol + '//d8rk54i4mohrb.cloudfront.net/css/p/$sr_pub_id.css';
    (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(s);
  })();
</script>
SRSLIDE_SCRIPT_TAG;

    return $content . $rv;
}

/**
 * srslide_admin_init
 * Inititalize admin / register and load srslide.css
 *
 * @access public
 * @return void
 */
function srslide_admin_init()
{
    wp_register_style('srslide.css', SRSLIDE_PLUGIN_URL . 'srslide.css');
    wp_enqueue_style('srslide.css');
}

/**
 * Add the SimpleReach admin section
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return None
 */
function srslide_admin()
{
    include_once('srslide_admin.php');
}

/**
 * Add the SimpleReach admin options to the post CRUD page
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return None
 */
function srslide_admin_actions()
{
    include_once('srslide_post.php');
    add_options_page("SimpleReach Slide", "SimpleReach Slide", 1, "SimpleReach-Slide", "srslide_admin");
}

/**
 * Setup the locales for i18n
 *
 * @author Malaney Hill <engineering@simplereach.com>
 * @param None
 * @return None
 */
function srslide_textdomain()
{
        $locale        = apply_filters( 'srslide_locale', get_locale() );
        $mofile        = sprintf( 'srslide-%s.mo', $locale );
        $mofile_local  = SRSLIDE_PLUGIN_DIR . '/lang/' . $mofile;

        if (file_exists($mofile_local)) {
                return load_textdomain( 'srslide', $mofile_local );
        } else {
                return false;
	}
}

/**
 * Run the appropriate actions on hooks
 *
 * @author Malaney Hill <engineering@simplereach.com>
 * @param None
 * @return None
 */
function srslide_loaded()
{
	do_action('srslide_loaded');
}

if (is_admin()) {
    add_action('admin_init', 'srslide_admin_init');
}
add_filter('the_content', 'srslide_insert_slide');
add_action('admin_menu','srslide_admin_actions');
add_action('add_meta_boxes','srslide_post_meta_box');
add_action('save_post','srslide_post_save_data');
add_action('edit_post','srslide_post_save_data');
add_action ('srslide_loaded', 'srslide_textdomain', 2);
add_action('plugins_loaded', 'srslide_loaded', 20);
?>
