<?php

/**
 * Add The Slide options box to the post CRUD page
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return None
 */
function srslide_post_meta_box()
{
    if (function_exists('add_meta_box')) {
        add_meta_box('srslide',__('The Slide', 'srslide'), 'srslide_meta','post');
    }
}


/**
 * The code for The Slide options box on the post CRUD page
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return None
 */
function srslide_meta()
{
    global $post;
    $post_id = $post;
    if (is_object($post_id)) {
        $post_id = $post_id->ID;
    }

	wp_register_style('srslide.css', SRSLIDE_PLUGIN_URL . 'srslide.css');
	wp_enqueue_style('srslide.css');
    wp_nonce_field( plugin_basename(__FILE__), 'srslide_noncename' );

    $title 			= htmlspecialchars(stripcslashes(get_post_meta($post_id, '_srslide_title', true)));
    $article_icon 		= htmlspecialchars(stripcslashes(get_post_meta($post_id, '_srslide_article_icon', true)));
    $tags 			= htmlspecialchars(stripcslashes(get_post_meta($post_id, '_srslide_tags', true)));
    $disable_slide_on_post 	= htmlspecialchars(stripcslashes(get_post_meta($post_id, '_srslide_disable_on_post', true)));
    ?>
    <div id="srslide_meta_box">
    <input value='srslide_edit' type='hidden' name='srslide_edit' />
        <table>
            <tr>
                <th><?php print __('Title:', 'srslide') ?></th>
                <td><input value="<?php echo $title ?>" type="text" name="srslide_title" size="60" /></td>
            </tr>
            <tr>
                <th scope="row"><?php print __('Article Icon URL:', 'srslide') ?></th>
                <td><input value="<?php echo $article_icon ?>" type="text" name="srslide_article_icon" size="60" /></td>
            </tr>
            <tr>
                <th scope="row"><?php print __('Tags:', 'srslide') ?></th>
                <td><input value="<?php echo $tags ?>" type="text" name="srslide_tags" size="60" /></td>
            </tr>
            <tr>
                <th scope="row"><?php print __('Disable Slide on post:', 'srslide') ?></th>
                <td><input name="srslide_disable_on_post" id="srslide_disable_on_post" type="checkbox" <?php if ($disable_slide_on_post) echo 'checked="1"'; ?> /></td>
            </tr>
        </table>
    </div>
    <?php
}

/**
 * Save the post meta data for The Slide
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param Integer Post ID
 * @return None
 */
function srslide_post_save_data($post_id)
{
    // Ignore if auto-saving
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }

    // verify this came from the our screen and with proper authorization,
    // because save_post can be triggered at other times
    if (!wp_verify_nonce($_POST['srslide_noncename'], plugin_basename(__FILE__))) {
        return $post_id;
    }

    // Check permissions
    if ('page' == $_POST['post_type']) {
        if (!current_user_can( 'edit_page', $post_id ))
            return $post_id;
    } else {
        if (!current_user_can( 'edit_post', $post_id ))
            return $post_id;
    }

    // OK, we're auth'd, time to make the donuts
    global $post;
    $id = $post;
    if (is_object($id)) {
        $id = $post->ID;
    }

    $disable_slide_on_post	= (!empty($_POST['srslide_disable_on_post'])) 	? $_POST['srslide_disable_on_post'] : '';
    $title			= (!empty($_POST['srslide_title'])) 		? $_POST['srslide_title'] : '';
    $tags 			= (!empty($_POST['srslide_tags'])) 		? $_POST['srslide_tags'] : '';
    $icon 			= (!empty($_POST['srslide_article_icon'])) 	? $_POST['srslide_article_icon'] : '';

    // Clear everything out first to start with a clean slate
    delete_post_meta($id, '_srslide_title');
    delete_post_meta($id, '_srslide_tags');
    delete_post_meta($id, '_srslide_article_icon');
    delete_post_meta($id, '_srslide_disable_on_post');

    // Ignore if the slide should be hidden
    if(isset($disable_slide_on_post) && !empty($disable_slide_on_post)) {
        add_post_meta($id, '_srslide_disable_on_post', true);
        // We don't just return here because we want to save the data anyway
        // SimpleReach will index this post even though The Slide is disabled
    } else {
        // Add this anyway to ensure we show the slide
        add_post_meta($id, '_srslide_disable_on_post', false);
    }

    // Set to post title if the field is empty
    if (empty($title)) {
        if (!empty($_POST['post_title'])) {
            add_post_meta($id, '_srslide_title', $_POST['post_title']);
        }
    } else {
        add_post_meta($id, '_srslide_title', $title);
    }

    // Set to post tags if the field is empty
    if (empty($tags)) {
        $tagset = array();
        foreach (wp_get_post_tags($id) as $tag) {
	    $tagset[] = $tag->name;
        }
        add_post_meta($id, '_srslide_tags', join(",", $tagset));
    } else {
        add_post_meta($id, '_srslide_tags', $tags);
    }

    if (!empty($icon)) {
        add_post_meta($id, '_srslide_article_icon', $icon);
    }

}
?>
